@@ -1,5 +1,5 @@
-/* $Id: game_events.cpp 14656 2006-12-14 02:18:25Z sapient $ */
-/* $Id: game_events.cpp 14656 2006-12-14 02:18:25Z sapient $ */
+/* $Id: game_events.cpp 14883 2006-12-27 13:35:38Z boucman $ */
+/* $Id: game_events.cpp 14883 2006-12-27 13:35:38Z boucman $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -538,6 +538,7 @@ bool event_handler::handle_event_command(const queued_event& event_info,
 		std::string side = cfg["side"];
 		std::string income = cfg["income"];
 		std::string team_name = cfg["team_name"];
+		std::string user_team_name = cfg["user_team_name"];
 		std::string gold = cfg["gold"];
 		wassert(state_of_game != NULL);
 		side = utils::interpolate_variables_into_string(side, *state_of_game);
@@ -551,7 +552,8 @@ bool event_handler::handle_event_command(const queued_event& event_info,
 			std::cerr << "modifying team: " << team_index << "\n";
 			if(!team_name.empty()) {
 				std::cerr << "change team to team_name '" << team_name << "'\n";
-				(*teams)[team_index].change_team(team_name);
+				(*teams)[team_index].change_team(team_name,
+												 user_team_name);
 			}
 
 			if(!income.empty()) {
