@@ -1,4 +1,4 @@
-/* $Id: multiplayer_wait.cpp 14131 2006-11-01 12:38:03Z rusty $ */
+/* $Id: multiplayer_wait.cpp 14883 2006-12-27 13:35:38Z boucman $ */
 /*
    Copyright (C)
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
@@ -425,7 +425,7 @@ void wait::generate_menu()
 			str << sd["income"] << _(")");
 		}
 
-		str	<< COLUMN_SEPARATOR << sd["team_name"];
+		str	<< COLUMN_SEPARATOR << sd["user_team_name"];
 		str << COLUMN_SEPARATOR << get_colour_string(lexical_cast_default<int>(sd["colour"], 0) - 1);
 		details.push_back(str.str());
 	}
