@@ -1,4 +1,4 @@
-/* $Id: pathfind.hpp 7396 2005-07-02 21:37:20Z ott $ */
+/* $Id: pathfind.hpp 11699 2006-05-29 10:11:22Z rusty $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -46,19 +46,19 @@ enum VACANT_TILE_TYPE { VACANT_CASTLE, VACANT_ANY };
 //
 //if no valid location can be found, it will return a null location.
 gamemap::location find_vacant_tile(const gamemap& map,
-                                   const std::map<gamemap::location,unit>& un,
+                                   const unit_map& un,
                                    const gamemap::location& loc,
                                    VACANT_TILE_TYPE vacancy=VACANT_ANY);
 
 //function which determines if a given location is an enemy zone of control
-bool enemy_zoc(gamemap const &map, gamestatus const &status,
-               std::map<gamemap::location, unit> const &units,
+bool enemy_zoc(gamemap const &map,
+               unit_map const &units,
                std::vector<team> const &teams, gamemap::location const &loc,
-               team const &current_team, int side);
+               team const &viewing_team, unsigned int side);
 
 struct cost_calculator
 {
-	virtual double cost(const gamemap::location& loc, const double so_far, const bool isDst) const = 0;
+	virtual double cost(const gamemap::location& src, const gamemap::location& loc, const double so_far, const bool isDst) const = 0;
 	virtual ~cost_calculator() {}
 	inline double getNoPathValue(void) const { return (42424242.0); }
 };
@@ -75,11 +75,13 @@ struct paths
 	//additional_turns: if 0, paths for how far the unit can move this turn
 	//will be calculated. If 1, paths for how far the unit can move by the
 	//end of next turn will be calculated, and so forth.
+	//viewing_team is usually current team, except for Show Enemy Moves etc.
 	paths(gamemap const &map, gamestatus const &status,
 	      game_data const &gamedata,
-	      std::map<gamemap::location, unit> const &units,
+	      unit_map const &units,
 	      gamemap::location const &loc, std::vector<team> const &teams,
-	      bool ignore_zocs, bool allow_teleport, int additional_turns = 0);
+	      bool ignore_zocs, bool allow_teleport,
+		  const team &viewing_team, int additional_turns = 0);
 
 	//structure which holds a single route between one location and another.
 	struct route
@@ -87,6 +89,7 @@ struct paths
 		route() : move_left(0) {}
 		std::vector<gamemap::location> steps;
 		int move_left; //movement unit will have left at end of the route.
+		std::map<gamemap::location, int> turn_waypoints;
 	};
 
 	typedef std::map<gamemap::location,route> routes_map;
@@ -100,15 +103,16 @@ paths::route a_star_search(gamemap::location const &src, gamemap::location const
 
 //function which, given a unit and a route the unit can move on, will
 //return the number of turns it will take the unit to traverse the route.
+//adds "turn waypoints" to rt.turn_waypoints. note that "end of path" is also added.
 int route_turns_to_complete(const unit& u, const gamemap& map,
-                            const paths::route& rt);
+                            paths::route& rt);
 
 struct shortest_path_calculator : cost_calculator
 {
 	shortest_path_calculator(const unit& u, const team& t,
 	                         const unit_map& units, const std::vector<team>& teams,
-	                         const gamemap& map, const gamestatus& status);
-	virtual double cost(const gamemap::location& loc, const double so_far, const bool isDst) const;
+	                         const gamemap& map);
+	virtual double cost(const gamemap::location& src, const gamemap::location& loc, const double so_far, const bool isDst) const;
 
 private:
 	unit const &unit_;
@@ -116,10 +120,20 @@ private:
 	unit_map const &units_;
 	std::vector<team> const &teams_;
 	gamemap const &map_;
-	int const lawful_bonus_;
-	bool const unit_is_skirmisher_;
 	int const movement_left_;
 	int const total_movement_;
 };
 
+//function which only uses terrain, ignoring shroud, enemies, etc.
+//required by move_unit_fake if the normal path fails.
+struct emergency_path_calculator : cost_calculator
+{
+	emergency_path_calculator(const unit& u, const gamemap& map);
+	virtual double cost(const gamemap::location& src, const gamemap::location& loc, const double so_far, const bool isDst) const;
+
+private:
+	unit const &unit_;
+	gamemap const &map_;
+};
+
 #endif
