@@ -1,4 +1,4 @@
-/* $Id: playcampaign.cpp 14736 2006-12-19 10:37:39Z edb $ */
+/* $Id: playcampaign.cpp 15083 2007-01-05 17:53:44Z jhinrichs $ */
 /*
    Copyright (C) 2003-2005 by David White <davidnwhite@verizon.net>
    Copyright (C) 2005 by Philippe Plantier <ayin@anathas.org>
@@ -336,10 +336,17 @@ LEVEL_RESULT play_game(display& disp, game_state& state, const config& game_conf
 
 		if(io_type == IO_CLIENT) {
 			config cfg;
+
+			std::string msg;
+			if (state.scenario.empty())
+				msg = _("Receiving data...");
+			else
+				msg = _("Downloading next scenario...");
+
 			do {
 				cfg.clear();
 				network::connection data_res = gui::network_receive_dialog(disp,
-						_("Downloading next level..."), cfg);
+						msg, cfg);
 				if(!data_res)
 					throw network::error(_("Connection timed out"));
 			} while(cfg.child("next_scenario") == NULL &&
@@ -394,7 +401,7 @@ LEVEL_RESULT play_game(display& disp, game_state& state, const config& game_conf
 				// Adds player information, and other state
 				// information, to the configuration object
 				wassert(cfg.child("next_scenario") != NULL);
-				write_game(state, *cfg.child("next_scenario")/*, WRITE_SNAPSHOT_ONLY*/);
+				write_game(state, *cfg.child("next_scenario"), WRITE_SNAPSHOT_ONLY);
 				network::send_data(cfg);
 
 			} else if(io_type == IO_SERVER && scenario == NULL) {
