@@ -1,4 +1,4 @@
-/* $Id: menu.hpp 11788 2006-06-01 20:20:30Z sapient $ */
+/* $Id: menu.hpp 15122 2007-01-07 12:28:17Z isaac $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -86,6 +86,15 @@ public:
 		bool load_failed_;
 		int normal_rgb2_, selected_rgb2_, heading_rgb2_;
 		double normal_alpha2_, selected_alpha2_, heading_alpha2_;
+		struct bg_cache
+		{
+			bg_cache() : width(-1), height(-1)
+			{}
+
+			surface surf;
+			int width, height;
+		};
+		bg_cache bg_cache_;
 	};
 	friend class style;
 	friend class imgsel_style;
