@@ -1,4 +1,4 @@
-/* $Id: slider.hpp 12604 2006-07-17 09:54:21Z isaac $ */
+/* $Id: slider.hpp 14951 2006-12-31 16:19:24Z edb $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -37,6 +37,8 @@ public:
 	int max_value() const;
 	int min_value() const;
 
+	bool value_change();
+
 	virtual void enable(bool new_val=true);
 
 	//VC++ doesn't like a 'using scrollarea::set_location' directive here, so we declare
@@ -61,6 +63,8 @@ private:
 	int value_;
 	int increment_;
 
+	bool value_change_;
+
 	enum STATE { UNINIT, NORMAL, ACTIVE, CLICKED, DRAGGED };
 	STATE state_;
 };
